// Create dummy functions to hide the indirection
// inherient in invoking dll entry points.


#if !defined ( K8055_FIXUP_INCLUDED )
#define K8055_FIXUP_INCLUDED

#define IDLE 0
#define COOLING 1
#define HEATING 2

// Gain of the Op-Amp on k8055 board
#define GAIN 2.0

// Measured value of fixed resistor in lower arm of
// thermistor voltage divider
#define R1 47500.0

#if !defined ( LINUX_COMPILE )

// Running on VC
// Need to invoke functions indirectly (through function pointers)
// because of the way the dll is loaded. (at least in VC 6.0)

#include "K8055D.h"
#include "windows.h"

// typedefs here help compiler check number and kind of arguments
// during indirect invocations (via following function pointers) 

typedef long ( __stdcall *LONG2LONG ) ( long ) ;
typedef void ( __stdcall *VOID2VOID ) ( void ) ;
typedef void ( __stdcall *VOID2LONGPTR2 ) ( long*, long* ) ;
typedef void ( __stdcall *VOID2LONGLONG ) ( long, long ) ;
typedef int  ( __stdcall *INT2LONG ) ( long ) ;
typedef int  ( __stdcall *INT2VOID ) ( void ) ;
typedef void ( __stdcall *VOID2LONG ) ( long ) ;

// These will be set to point to the entry points as discovered
// in the dll

#ifdef __cplusplus
extern "C" {
#endif  // c++

extern LONG2LONG     OpenDevicePtr ;
extern VOID2VOID     CloseDevicePtr ;
extern VOID2LONGPTR2 ReadAllAnalogPtr ;
extern LONG2LONG     ReadAnalogChannelPtr ;
extern VOID2LONGLONG OutputAnalogChannelPtr ;
extern VOID2LONGPTR2 OutputAllAnalogPtr ;
extern VOID2LONG     ClearAnalogChannelPtr ;
extern VOID2LONG     ClearAllAnalogPtr ;
extern VOID2LONG     SetAnalogChannelPtr ;
extern VOID2VOID     SetAllAnalogPtr ;
extern VOID2LONG     WriteAllDigitalPtr ;
extern VOID2LONG     ClearDigitalChannelPtr ;
extern VOID2VOID     ClearAllDigitalPtr ;
extern VOID2LONG     SetDigitalChannelPtr ;
extern VOID2VOID     SetAllDigitalPtr ;
extern INT2LONG      ReadDigitalChannelPtr ;
extern INT2VOID      ReadAllDigitalPtr ;
extern LONG2LONG     ReadCounterPtr ;
extern VOID2LONG     ResetCounterPtr ;
extern VOID2LONGLONG SetCounterDebounceTimePtr ;

#ifdef __cplusplus
}
#endif  // c++

#define OpenDeviceWrapper( cardNo ) ( ( *OpenDevicePtr ) ( cardNo ) )
#define CloseDeviceWrapper() ( ( *CloseDevicePtr ) ( ) ) 
#define ReadAnalogChannelWrapper( Channel) ( ( *ReadAnalogChannelPtr) ( Channel) )
#define ReadAllAnalogWrapper(Data1, Data2) ( ( *ReadAllAnalogPtr) (Data1, Data2) )
#define OutputAnalogChannelWrapper(Channel, Data) ( ( *OutputAnalogChannelPtr) (Channel, Data))
#define OutputAllAnalogWrapper(Data1, Data2) ( ( *OutputAllAnalogPtr) (Data1, Data2))
#define ClearAnalogChannelWrapper(Channel) ( ( *ClearAnalogChannelPtr) (Channel)) 
#define ClearAllAnalogWrapper() ( ( *ClearAllAnalogPtr) ( ) )
#define SetAnalogChannelWrapper(Channel) ( ( *SetAnalogChannelPtr) (Channel)) 
#define SetAllAnalogWrapper() ( ( *SetAllAnalogPtr) ( ) )
#define WriteAllDigitalWrapper(Data) ( ( *WriteAllDigitalPtr) (Data))
#define ClearDigitalChannelWrapper(Channel) ( ( *ClearDigitalChannelPtr) (Channel))
#define ClearAllDigitalWrapper() ( ( *ClearAllDigitalPtr) ( ) )
#define SetDigitalChannelWrapper(Channel) ( ( *SetDigitalChannelPtr) (Channel))
#define SetAllDigitalWrapper() ( ( *SetAllDigitalPtr) ( ) )
#define ReadDigitalChannelWrapper(Channel) ( ( *ReadDigitalChannelPtr) (Channel))
#define ReadAllDigitalWrapper() ( ( *ReadAllDigitalPtr) ( ) )
#define ReadCounterWrapper(CounterNr) ( ( *ReadCounterWrapperPtr) (CounterNr) )
#define ResetCounterWrapper(CounterNr) ( ( *ResetCounterPtr) (CounterNr) )
#define SetCounterDebounceTimeWrapper(CounterNr, DebounceTime) ( ( *SetCounterDebounceTimePtr) (CounterNr, DebounceTime))

#ifdef __cplusplus
extern "C" {
#endif  // c++

void InitWrappers ( char* libName ) ;

#ifdef __cplusplus
}
#endif  // c++

// Define Windows sleep function
#define sleepSeconds( x ) ( Sleep ( 10 * x ) )

#else  // Running on Linux

#include <unistd.h>  // For sleep ( ) function

// We can invoke the functions in the so directly.

#define OpenDeviceWrapper( cardNo ) ( OpenDevice  ( cardNo ) )
#define CloseDeviceWrapper( ) ( CloseDevice  ( ) ) 
#define ReadAnalogChannelWrapper( Channel) ( ReadAnalogChannel ( Channel ) )
#define ReadAllAnalogWrapper(Data1, Data2) ( ReadAllAnalog ( Data1, Data2 ) )
#define OutputAnalogChannelWrapper(Channel, Data) ( OutputAnalogChannel (Channel, Data))
#define OutputAllAnalogWrapper(Data1, Data2) ( OutputAllAnalog (Data1, Data2))
#define ClearAnalogChannelWrapper(Channel) ( ClearAnalogChannel (Channel)) 
#define ClearAllAnalogWrapper() ( ClearAllAnalog ( ) )
#define SetAnalogChannelWrapper(Channel) ( SetAnalogChannel (Channel)) 
#define SetAllAnalogWrapper() ( SetAllAnalog ( ) )
#define WriteAllDigitalWrapper(Data) ( WriteAllDigital (Data))
#define ClearDigitalChannelWrapper(Channel) ( ClearDigitalChannel (Channel))
#define ClearAllDigitalWrapper() ( ClearAllDigital ( ) )
#define SetDigitalChannelWrapper(Channel) ( SetDigitalChannel (Channel))
#define SetAllDigitalWrapper() ( SetAllDigital ( ) )
#define ReadDigitalChannelWrapper(Channel) ( ReadDigitalChannel (Channel))
#define ReadAllDigitalWrapper() ( ReadAllDigital ( ) )
#define ReadCounterWrapper(CounterNr) ( ReadCounterWrapper (CounterNr) )
#define ResetCounterWrapper(CounterNr) ( ResetCounter (CounterNr) )
#define SetCounterDebounceTimeWrapper(CounterNr, DebounceTime) ( SetCounterDebounceTime (CounterNr, DebounceTime))

// Define Linux sleep function
#define sleepSeconds( secs ) ( sleep ( secs ) )

#endif  // Running on Linux

#endif  // Header not already included
